Index: media/base/media_log.cc |
diff --git a/media/base/media_log.cc b/media/base/media_log.cc |
index 754a5f924cee03f1dd8476993660f47165aeb199..d0890c26cb895e3ee6d82a7ec33931e3061d0392 100644 |
--- a/media/base/media_log.cc |
+++ b/media/base/media_log.cc |
@@ -216,10 +216,12 @@ scoped_ptr<MediaLogEvent> MediaLog::CreateVideoSizeSetEvent( |
} |
scoped_ptr<MediaLogEvent> MediaLog::CreateBufferedExtentsChangedEvent( |
- int64 start, int64 current, int64 end) { |
+ int64_t start, |
+ int64_t current, |
+ int64_t end) { |
scoped_ptr<MediaLogEvent> event( |
CreateEvent(MediaLogEvent::BUFFERED_EXTENTS_CHANGED)); |
// These values are headed to JS where there is no int64 so we use a double |
// and accept loss of precision above 2^53 bytes (8 Exabytes). |
event->params.SetDouble("buffer_start", start); |
event->params.SetDouble("buffer_current", current); |
@@ -216,10 +216,12 @@ scoped_ptr<MediaLogEvent> MediaLog::CreateVideoSizeSetEvent( |
scoped_ptr<MediaLogEvent> event( |
CreateEvent(MediaLogEvent::BUFFERED_EXTENTS_CHANGED)); |
- // These values are headed to JS where there is no int64 so we use a double |
+ // These values are headed to JS where there is no int64_t so we use a double |
// and accept loss of precision above 2^53 bytes (8 Exabytes). |
event->params.SetDouble("buffer_start", start); |